/*-------------------------------------------------------------------------+
| Copyright 2016 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.introspection.details.handler;

import org.fortiss.tooling.common.ui.javafx.control.treetableview.DynamicTreeContentProviderBase;
import org.fortiss.tooling.common.ui.javafx.control.treetableview.DynamicTreeTableViewer;
import org.fortiss.tooling.kernel.introspection.items.EObjectAwareKISSDetailsItemBase;
import org.fortiss.tooling.kernel.introspection.items.LibraryKISSDetailsItem;
import org.fortiss.tooling.kernel.service.ILibraryService;

import javafx.scene.Node;

/**
 * {@link KISSDetailsUIHandlerBase} for {@link ILibraryService}.
 * 
 * @author hoelzl
 */
public final class LibraryKISSDetailsUIHandler
		extends EObjectAwareKISSDetailsUIHandlerBase {

	/** {@inheritDoc} */
	@Override
	public Node createDisplayControl() {
		String heading = "Type to search registered library element handler:";
		String footer = "Number of currently registered library element handlers: " +
				getRootObject().countHandlers();
		return createFilteredTree(heading, footer);
	}

	/** {@inheritDoc} */
	@Override
	protected void createTreeColumns(DynamicTreeTableViewer<Object> tree) {
		createDefaultTreeColumns(tree, "Class / Provider", 250, "Provider Class", 400,
				"EObject Class", 400);
	}

	/** {@inheritDoc} */
	@Override
	protected DynamicTreeContentProviderBase<Object> createContentProvider() {
		return new EObjectAwareTreeContentProviderBase() {
			@Override
			protected EObjectAwareKISSDetailsItemBase<?> getInputObject() {
				return LibraryKISSDetailsUIHandler.this.getRootObject();
			}
		};
	}

	/** {@inheritDoc} */
	@Override
	protected LibraryKISSDetailsItem getRootObject() {
		return (LibraryKISSDetailsItem)dataItem;
	}
}
